@@ -145,7 +145,7 @@ module Bundler
     def debug
       if ENV['DEBUG_RESOLVER']
         debug_info = yield
-        debug_info = debug_info.inpsect unless debug_info.is_a?(String)
+        debug_info = debug_info.inspect unless debug_info.is_a?(String)
         $stderr.puts debug_info
       end
     end
@@ -179,15 +179,15 @@ module Bundler
           activated[a.name] ? 0 : gems_size(a) ]
       end
 
-      debug { "Activated:\n" + activated.values.map { |a| "  #{a.name} (#{a.version})" }.join("\n") }
-      debug { "Requirements:\n" + reqs.map { |r| "  #{r.name} (#{r.requirement})"}.join("\n") }
+      debug { "Activated:\n" + activated.values.map {|a| "  #{a}" }.join("\n") }
+      debug { "Requirements:\n" + reqs.map {|r| "  #{r}"}.join("\n") }
 
       activated = activated.dup
 
       # Pull off the first requirement so that we can resolve it
       current = reqs.shift
 
-      debug { "Attempting:\n  #{current.name} (#{current.requirement})"}
+      debug { "Attempting:\n  #{current}"}
 
       # Check if the gem has already been activated, if it has, we will make sure
       # that the currently activated gem satisfies the requirement.
@@ -279,14 +279,6 @@ module Bundler
             end
             raise GemNotFound, message
           else
-            if @missing_gems[current] >= 5
-              message =  "Bundler could not find find gem #{current.required_by.last},"
-              message << "which is required by gem #{current}."
-              raise GemNotFound, message
-            end
-            @missing_gems[current] += 1
-
-            debug { "    Could not find #{current} by #{current.required_by.last}" }
             @errors[current.name] = [nil, current]
           end
         end
@@ -356,7 +348,8 @@ module Bundler
 
     def search(dep)
       if base = @base[dep.name] and base.any?
-        d = Gem::Dependency.new(base.first.name, *[dep.requirement.as_list, base.first.version].flatten)
+        reqs = [dep.requirement.as_list, base.first.version.to_s].flatten.compact
+        d = Gem::Dependency.new(base.first.name, *reqs)
       else
         d = dep.dep
       end
@@ -407,7 +400,7 @@ module Bundler
     end
 
     def error_message
-      output = errors.inject("") do |o, (conflict, (origin, requirement))|
+      errors.inject("") do |o, (conflict, (origin, requirement))|
 
         # origin is the SpecSet of specs from the Gemfile that is conflicted with
         if origin
@@ -420,18 +413,18 @@ module Bundler
           # If the origin is "bundler", the conflict is us
           if origin.name == "bundler"
             o << "  Current Bundler version:\n"
-            newer_bundler_required = requirement.requirement > Gem::Requirement.new(origin.version)
+            other_bundler_required = !requirement.requirement.satisfied_by?(origin.version)
           # If the origin is a LockfileParser, it does not respond_to :required_by
-          elsif !origin.respond_to?(:required_by) || !(required_by = origin.required_by.first)
+          elsif !origin.respond_to?(:required_by) || !(origin.required_by.first)
             o << "  In snapshot (Gemfile.lock):\n"
           end
 
           o << gem_message(origin)
 
           # If the bundle wants a newer bundler than the running bundler, explain
-          if origin.name == "bundler" && newer_bundler_required
-            o << "Your version of Bundler is older than the one requested by the Gemfile.\n"
-            o << "Perhaps you need to update Bundler by running `gem install bundler`."
+          if origin.name == "bundler" && other_bundler_required
+            o << "This Gemfile requires a different version of Bundler.\n"
+            o << "Perhaps you need to update Bundler by running `gem install bundler`?"
           end
 
         # origin is nil if the required gem and version cannot be found in any of
@@ -456,7 +449,8 @@ module Bundler
           # the rest of the time, the gem cannot be found because it does not exist in the known sources
           else
             if requirement.required_by.first
-              o << "Could not find gem '#{clean_req(requirement)}', required by '#{clean_req(requirement.required_by.first)}', in any of the sources\n"
+              o << "Could not find gem '#{clean_req(requirement)}', which is required by "
+              o << "gem '#{clean_req(requirement.required_by.first)}', in any of the sources."
             else
               o << "Could not find gem '#{clean_req(requirement)} in any of the sources\n"
             end
